GenORM
======


**GenORM is** is a simple to use Object Related Modeler which offers an opportunity
to build Python class based data applciation model without clear understanding about
how to store, manipulate or get data to or from database engine. It works with both
most popular multiplatform database engines - MySQL and PostgreSQL.

For documentation its good to visit official documentation site:
<<under construction due [beta]>>
